@@ -32,16 +32,32 @@ from ocrfeeder.util.graphics import getImagePrintSize
 from ocrfeeder.util.lib import debug
 from reportlab.pdfgen import canvas
 from reportlab.lib import units
-from reportlab.lib.utils import ImageReader
+from reportlab.lib.utils import ImageReader, simpleSplit
 import math
 import os.path
 import shutil
 import tempfile
 
-class DocumentGenerator:
+class DocumentGeneratorManager(object):
+
+    GENERATORS = {}
 
     def __init__(self):
-        self.document = self.makeDocument()
+        pass
+
+    def register(self, id, generator):
+        self.GENERATORS[id] = generator
+
+    def get(self, id):
+        return self.GENERATORS.get(id)
+
+    def getFormats(self):
+        return self.GENERATORS.keys()
+
+class DocumentGenerator(object):
+
+    def __init__(self):
+        pass
 
     def makeDocument(self):
         raise NotImplementedError('Method not defined!')
@@ -345,6 +361,9 @@ class PlaintextGenerator(DocumentGenerator):
     def addText(self, newText):
         self.text += newText
 
+    def addPage(self, page):
+        self.addText(page.getTextFromBoxes())
+
     def save(self):
         try:
             # This will create a new file or **overwrite an existing file
@@ -376,13 +395,13 @@ class PdfGenerator(DocumentGenerator):
         text.setCharSpace(box.text_data.letter_space)
         text.setLeading(box.text_data.line_space + box.text_data.size)
         text.moveCursor(0, box.text_data.size)
-        try:
-            self.setFont(box.text_data.face,
-                         box.text_data.size)
-        except:
-            debug('Error setting font %s' % box.text_data.face)
-            self.canvas.setFontSize(box.text_data.size)
-        text.textLines(box.text)
+        #todo: efficiently add the required font
+        self.canvas.setFontSize(box.text_data.size)
+        lines = simpleSplit(box.text,
+                            self.canvas._fontname,
+                            box.text_data.size,
+                            box.width)
+        text.textLines('\n'.join(lines))
         self.canvas.drawText(text)
 
     def addImage(self, box):
@@ -414,3 +433,9 @@ class PdfGenerator(DocumentGenerator):
 
     def save(self):
         self.canvas.save()
+
+manager = DocumentGeneratorManager()
+manager.register('HTML', HtmlGenerator)
+manager.register('ODT', OdtGenerator)
+manager.register('TXT', PlaintextGenerator)
+manager.register('PDF', PdfGenerator)
