@@ -28,12 +28,14 @@ from ocrfeeder.studio.dataHolder import TEXT_TYPE, IMAGE_TYPE
 from ocrfeeder.util import lib
 IMAGE_ARGUMENT = '$IMAGE'
 FILE_ARGUMENT = '$FILE'
+LANGUAGE_ARGUMENT = '$LANG'
 
 class Engine:
 
     def __init__(self, name, engine_path, arguments,
                  image = None, temporary_folder = '/tmp/',
                  image_format = 'PPM', failure_string = '',
+                 languages = '', language_argument = '',
                  version = 0.0):
 
         self.name = name
@@ -50,8 +52,11 @@ class Engine:
             self.image_path = self.setImage(image)
         self.image_format = image_format
         self.failure_string = failure_string
+        self.language_argument = language_argument
+        self.setLanguages(languages)
         self.temporary_folder = temporary_folder
         self.__color_information = None
+        self.setLanguage('')
 
     def setImage(self, image):
         image_file = tempfile.mkstemp(dir = self.temporary_folder,
@@ -69,6 +74,20 @@ class Engine:
         if self.arguments.find(FILE_ARGUMENT) != -1:
             file_name = tempfile.mkstemp(dir = self.temporary_folder)[1]
             parsed_arguments = parsed_arguments.replace(FILE_ARGUMENT, file_name)
+
+        if self._favorite_language:
+            if self.languages:
+                favorite_language = self.languages.get(self._favorite_language, '')
+                if not favorite_language:
+                    values = self.languages.values()
+                    if values:
+                        favorite_language = values[0]
+                parsed_arguments = parsed_arguments.replace(LANGUAGE_ARGUMENT,
+                                         '%s %s' % (self.language_argument,
+                                                    favorite_language))
+        else:
+            parsed_arguments = parsed_arguments.replace(LANGUAGE_ARGUMENT, '')
+
         text = os.popen(self.engine_path + ' ' + parsed_arguments).read()
         try:
             try:
@@ -114,6 +133,8 @@ class Engine:
                        'arguments': self.arguments,
                        'image_format': self.image_format,
                        'failure_string': self.failure_string,
+                       'language_argument': self.language_argument,
+                       'languages': self.serializeLanguages(self.languages),
                        'version': self.version}
         root = ET.Element('engine')
         for key, value in engine_info.items():
@@ -123,6 +144,37 @@ class Engine:
             subelement.text = str(value)
         return ET.ElementTree(root).write(file_path, 'UTF-8')
 
+    def unserializeLanguages(self, languages):
+        langs_dict = {}
+        langs_list = languages.split(',')
+        for language in langs_list:
+            language_split = language.split(':')
+            if len(language_split) == 2:
+                langs_dict[language_split[0]] = language_split[1]
+        return langs_dict
+
+    def serializeLanguages(self, language_dict):
+        return ','.join(['%s:%s' % (lang, engine_lang)
+                         for lang, engine_lang in language_dict.items()])
+
+    def hasLanguages(self):
+        return self.languages and self.language_argument and \
+            self.arguments.find(LANGUAGE_ARGUMENT) != -1
+
+    def setLanguages(self, languages):
+        self._languages = self.unserializeLanguages(languages)
+
+    def getLanguages(self):
+        return self._languages
+
+    def setLanguage(self, language):
+        self._favorite_language = language
+
+    def getLanguage(self):
+        return self._favorite_language
+
+    languages = property(getLanguages, setLanguages)
+
 class OcrEnginesManager:
 
     def __init__(self, configuration_manager):
@@ -151,12 +203,9 @@ class OcrEnginesManager:
         self.ocr_engines = []
         favorite_engine_exists = False
         for xml_file in self.getXmlFilesInFolder(folder):
-            try:
-                engine = self.getEngineFromXml(xml_file)
+            engine = self.getEngineFromXml(xml_file)
+            if engine:
                 self.ocr_engines.append((engine, xml_file))
-            except WrongSettingsForEngine, we:
-                lib.debug("Cannot load engine at %s: %s" %( xml_file, str(we)))
-            else:
                 favorite_engine_exists = favorite_engine_exists or \
                     self.configuration_manager.favorite_engine == engine.name
         if not len(self.ocr_engines):
@@ -184,6 +233,8 @@ class OcrEnginesManager:
     def migrateEngine(self, engine, configuration, only_version = False):
         if not only_version:
             engine.arguments = configuration['arguments']
+            engine.language_argument = configuration['language_argument']
+            engine.setLanguages(configuration['languages'])
         engine.version = configuration['version']
         self.replaceEngine(engine, engine)
 
@@ -195,19 +246,31 @@ class OcrEnginesManager:
             arg_name = child.tag
             arg_value = child.text
             arguments[arg_name] = arg_value
-        engine = Engine(**arguments)
-        engine.temporary_folder = self.configuration_manager.TEMPORARY_FOLDER
+
+        try:
+            engine = Engine(**arguments)
+        except TypeError, exception:
+            lib.debug('Error when unserializing engine: %s', exception.message)
+            engine = None
+        except WrongSettingsForEngine, we:
+            lib.debug("Cannot load engine at %s: %s" %( xml_file_name, str(we)))
+            engine = None
+        else:
+            engine.temporary_folder = self.configuration_manager.TEMPORARY_FOLDER
         return engine
 
     def getXmlFilesInFolder(self, folder):
         return [os.path.join(folder, file) for file in os.listdir(folder) if file.endswith('.xml')]
 
     def newEngine(self, name, engine_path, arguments,
-                  image_format, failure_string, version):
+                  image_format, failure_string, languages,
+                  language_argument, version):
         engine = Engine(name = name, engine_path = engine_path,
                         arguments = arguments, image_format = image_format,
                         temporary_folder = self.configuration_manager.TEMPORARY_FOLDER,
                         failure_string = failure_string,
+                        languages = languages,
+                        language_argument = language_argument,
                         version = version)
         return engine
 
