@@ -242,6 +242,7 @@ class ImageReviewer(gtk.HPaned):
     def addBoxEditor(self, box, data_box = None):
         if not data_box:
             data_box = DataBox()
+            data_box.setLanguage(self.configuration_manager.language)
             data_box.updateBoundsFromBox(box)
         self.boxes_dict[box] = data_box
         self.editor.setBoxes(box, data_box)
@@ -312,6 +313,8 @@ class ImageReviewer(gtk.HPaned):
         self.updateMainWindow()
 
     def performOcrForDataBox(self, data_box, engine):
+        if engine.hasLanguages():
+            engine.setLanguage(data_box.getLanguage())
         pixbuf_width = self.image_pixbuf.get_width()
         pixbuf_height = self.image_pixbuf.get_height()
         subpixbuf = self.image_pixbuf.subpixbuf(data_box.getX(),
@@ -497,11 +500,12 @@ class ImageReviewer_Controler:
         if finished:
             dialog.cancel()
 
-    def __addImage(self, image_path, select_image = True):
+    def __addImage(self, image_path, select_image = True, page_data = None):
         image_path = os.path.abspath(os.path.expanduser(image_path))
         if not os.path.isfile(image_path):
             return None
-        page_data = PageData(image_path)
+        if page_data is None:
+            page_data = PageData(image_path)
         iter = self.source_images_selector_widget.get_model().addImage(page_data)
         if select_image:
             path = \
@@ -666,7 +670,10 @@ class ImageReviewer_Controler:
             adjustment_size = None
         clean_text = self.configuration_manager.clean_text
 
-        layout_analysis = LayoutAnalysis(self.__getConfiguredOcrEngine(),
+        engine = self.__getConfiguredOcrEngine()
+        if engine.hasLanguages():
+            engine.setLanguage(self.configuration_manager.language)
+        layout_analysis = LayoutAnalysis(engine,
                                          window_size,
                                          improve_column_detection,
                                          column_min_width,
@@ -757,6 +764,8 @@ class ImageReviewer_Controler:
         return self.__askForFileName(extension = '.ocrf')
 
     def saveProject(self, project_name):
+        image_reviewer = self.__getCurrentReviewer()
+        image_reviewer.savePageData()
         if not project_name.endswith('.ocrf'):
             project_name += '.ocrf'
         pages_data = self.source_images_selector_widget.getAllPages()
@@ -775,8 +784,10 @@ class ImageReviewer_Controler:
                 self.clear()
             for index in range(0, len(pages)):
                 page = pages[index]
-                image_reviewer = self.__addImage(page.image_path,
-                                                 select_image = index == 0)
+                self.__addImage(page.image_path,
+                                select_image = index == 0,
+                                page_data = page)
+                image_reviewer = self.__getCurrentReviewer()
                 image_reviewer.updatePageData(page)
         open_dialog.destroy()
         return project_file
@@ -949,6 +960,8 @@ class Editor:
         self.box_editor.align_fill_button.connect('toggled', self.__setDataBoxAlign, ALIGN_FILL)
         self.box_editor.letter_spacing_spin.connect('value-changed', self.__setDataBoxLetterSpacing)
         self.box_editor.line_spacing_spin.connect('value-changed', self.__setDataBoxLineSpacing)
+        self.box_editor.ocr_combo_box.connect('changed', self._onOCREngineChanged)
+        self.box_editor.languages_combo.connect('changed', self._onLanguageChanged)
         self.box_editor.hide()
 
     def __updateBoxX(self, spin_button):
@@ -1027,6 +1040,21 @@ class Editor:
         line_spacing_button = line_spacing_button or self.box_editor.line_spacing_spin
         self.data_box.setLineSpacing(line_spacing_button.get_value())
 
+    def __setDataBoxLanguage(self, language = ''):
+        language = language or self.box_editor.getLanguage()
+        self.data_box.setLanguage(language)
+
+    def _onOCREngineChanged(self, combobox):
+        index = self.box_editor.getSelectedOcrEngine()
+        if index == -1:
+            return
+        engine = self.ocr_engines[index][0]
+        self.box_editor.setAvailableLanguages(engine.getLanguages().keys())
+
+    def _onLanguageChanged(self, combobox):
+        if self.data_box:
+            self.data_box.setLanguage(self.box_editor.getLanguage())
+
     def update(self, box):
         self.box = box
         x, y, width, height = self.data_box.updateBoundsFromBox(self.box)
@@ -1096,7 +1124,7 @@ class Editor:
         self.__setDataBoxFont()
         self.__setDataBoxLetterSpacing()
         self.__setDataBoxLineSpacing()
-
+        self.__setDataBoxLanguage()
 
     def updateDataBox(self, data_box):
         self.__updating_data_box = True
@@ -1114,6 +1142,7 @@ class Editor:
         self.box_editor.setFontSize(self.data_box.text_data.size)
         self.box_editor.setLineSpacing(self.data_box.getLineSpacing())
         self.box_editor.setLetterSpacing(self.data_box.getLetterSpacing())
+        self.box_editor.setLanguage(self.data_box.getLanguage())
         self.__updating_data_box = False
         self.__connectDataBoxSignals()
         self.__updateBoxColor(None, self.data_box.type)
