@@ -113,7 +113,7 @@ class MainWindow:
                                   ('OCREngines', None, _('_OCR Engines'), None, _('Manage OCR engines'), menu_items['ocr_engines']),
                                   ('Unpaper', gtk.STOCK_EXECUTE, _('_Unpaper'), None, _('Process image with unpaper'), menu_items['unpaper']),
                                   ('ImageDeskewer', None, _('Image Des_kewer'),
-                                   None, _('Trie to straighten the image'),
+                                   None, _('Tries to straighten the image'),
                                    menu_items['image_deskewer']),
                                   ('Help', None, _('_Help')),
                                   ('HelpContents', gtk.STOCK_HELP, _('_Help'), 'F1', _('Help contents'), menu_items['help_contents']),
@@ -228,6 +228,93 @@ class MainWindow:
                           for action in actions]:
             gtkaction.set_sensitive(set_sensitive)
 
+class LanguagesComboBox(gtk.ComboBox):
+
+    _ID_COLUMN = 0
+    _LANG_COLUMN = 1
+    _CHECK_COLUMN = 2
+
+    def __init__(self, use_icon = False):
+        gtk.ComboBox.__init__(self)
+
+        self._cached_iters = {}
+        self._model_columns = (str, str)
+        if use_icon:
+            self._model_columns += (bool,)
+        model = gtk.ListStore(*self._model_columns)
+
+        self.set_model(model)
+
+        if use_icon:
+            renderer = gtk.CellRendererToggle()
+            renderer.set_sensitive(False)
+            self.pack_start(renderer, False)
+            self.add_attribute(renderer, 'active', self._CHECK_COLUMN)
+
+        renderer = gtk.CellRendererText()
+        # setting width so the combo won't be crazy large
+        renderer.set_property('width', 50)
+        self.pack_start(renderer, False)
+        self.add_attribute(renderer, 'text', self._LANG_COLUMN)
+
+        languages = lib.getLanguages()
+        sorted_keys = sorted(languages, key = lambda k: languages[k])
+        if sorted_keys:
+            values = ('', _('No language'))
+            if model.get_n_columns() == 3:
+                values += (False,)
+            model.append(values)
+        for key in sorted_keys:
+            language = languages[key]
+            translation = gettext.dgettext('iso_639', language)
+            values = (key, translation)
+            if model.get_n_columns() == 3:
+                values += (False,)
+            model.append(values)
+
+    def _getListStoreTypes(self):
+        return (str, str)
+
+    def setAvailableLanguages(self, languages):
+        model = self.get_model()
+        if model.get_n_columns() != 3:
+            return
+        cached_languages = self._cached_iters.keys()
+        languages_to_unset = [lang for lang in cached_languages
+                              if lang not in languages]
+        for lang in languages:
+            iter = self._cached_iters.get(lang)
+            if iter is None:
+                iter = model.get_iter_first()
+                while iter:
+                    if model.get_value(iter, self._ID_COLUMN) == lang:
+                        self._cached_iters[lang] = iter
+                        break
+                    iter = model.iter_next(iter)
+            if iter:
+                model.set_value(iter, self._CHECK_COLUMN, True)
+        for lang in languages_to_unset:
+            iter = self._cached_iters.get(lang)
+            if iter:
+                model.set_value(iter, self._CHECK_COLUMN, False)
+
+    def getLanguage(self):
+        iter = self.get_active_iter()
+        if iter:
+            return self.get_model().get_value(iter, self._ID_COLUMN)
+
+    def setLanguage(self, language):
+        iter = self._cached_iters.get(language)
+        model = self.get_model()
+        if not iter:
+            iter = model.get_iter_first()
+            while iter:
+                if model.get_value(iter, self._ID_COLUMN) == language:
+                    break
+                iter = model.iter_next(iter)
+        if iter:
+            self.set_active_iter(iter)
+
 class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
     __gtype_name__ = 'BoxEditor'
 
@@ -445,6 +532,9 @@ class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
 
         return self.align_left_button, self.align_center_button, self.align_right_button, self.align_fill_button
 
+    def getLanguage(self):
+        return self.languages_combo.getLanguage()
+
     def __makeOcrProperties(self, engines):
         hbox = gtk.HBox()
         self.perform_ocr_button = gtk.Button(_('OC_R'))
@@ -537,6 +627,15 @@ class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
             text_properties_notebook.append_page(angle_box, gtk.Label( _('Angle')))
             text_properties_notebook.set_tab_reorderable(angle_box, True)
 
+        label = gtk.Label( _('Mis_c'))
+        label.set_use_underline(True)
+        vbox = gtk.VBox()
+        language_frame = PlainFrame(_('Language'))
+        self.languages_combo = LanguagesComboBox(use_icon = True)
+        language_frame.add(self.languages_combo)
+        vbox.pack_start(language_frame, False, False, 0)
+        text_properties_notebook.append_page(vbox, label)
+
         vbox = gtk.VBox()
         label = gtk.Label(_('OCR engine to recogni_ze this area:'))
         label.set_mnemonic_widget(self.ocr_combo_box)
@@ -561,6 +660,11 @@ class BoxEditor(gtk.ScrolledWindow, gobject.GObject):
         vbox.pack_start(self.detect_angle_button, False)
         return vbox
 
+    def setAvailableLanguages(self, languages):
+        self.languages_combo.setAvailableLanguages(languages)
+
+    def setLanguage(self, language):
+        self.languages_combo.setLanguage(language)
 
     def setFontSize(self, size):
         font_name = self.font_button.get_font_name().split(' ')
@@ -1195,7 +1299,8 @@ class PreferencesDialog(gtk.Dialog):
         self.__makeToolsPreferences(self.__makeUnpaper(),
                                     self.__makeEngines(),
                                     self.__makePreProcessorPreferences())
-        self.__makeRecognitionPreferences(self.__makeTextPreferences(),
+        self.__makeRecognitionPreferences(self.__makeLanguagePreferences(),
+                                      self.__makeTextPreferences(),
                                       self.__makeWindowSize(),
                                       self.__makeColumnDetectionPreferences(),
                                       self.__makeBoundsAdjustmentsPreferences())
@@ -1231,6 +1336,7 @@ class PreferencesDialog(gtk.Dialog):
             self.__getBoundsAdjustmentSize()
         self.configuration_manager.deskew_images_after_addition = \
             self.deskew_images.get_active()
+        self.configuration_manager.language = self.language_combo.getLanguage()
         if self.configuration_manager.has_unpaper:
             self.configuration_manager.unpaper_images_after_addition = \
                 self.unpaper_images.get_active()
@@ -1553,6 +1659,29 @@ class PreferencesDialog(gtk.Dialog):
         unpaper_preferences.save()
         unpaper_preferences.destroy()
 
+    def __makeLanguagePreferences(self):
+        frame = PlainFrame(_('Language'))
+        self.language_combo = LanguagesComboBox(use_icon = False)
+        self.language_combo.setLanguage(self.configuration_manager.language)
+        vbox = gtk.VBox()
+        label = gtk.Label(_('The language may affect how the OCR engines work.\n'
+                        'If an engine is set to support languages but does not '
+                        'support the one chosen, it may result in blank text.\n'
+                        'You can choose "No Language" to prevent this.'))
+        alignment = gtk.Alignment(0, 0, 1, 0)
+        alignment.add(label)
+        vbox.pack_start(alignment, False, False, 12)
+        label = gtk.Label(_('Default _language:'))
+        label.set_use_underline(True)
+        label.set_mnemonic_widget(self.language_combo)
+        hbox = gtk.HBox()
+        hbox.pack_start(label, False, False, 12)
+        self.language_combo.set_size_request(250, -1)
+        hbox.pack_start(self.language_combo, False, True, 12)
+        vbox.pack_start(hbox, False, False, 0)
+        frame.add(vbox)
+        return frame
+
 class SystemEnginesDialog(gtk.Dialog):
 
     def __init__(self, engines):
@@ -1712,6 +1841,7 @@ class OcrSettingsDialog(gtk.Dialog):
         self.engine = engine
         self.vbox.add(self.__makeMainArea())
         self.set_icon_from_file(WINDOW_ICON)
+        self.configuration_manager = ConfigurationManager()
         self.vbox.show_all()
 
     def __makeMainArea(self):
@@ -1720,12 +1850,16 @@ class OcrSettingsDialog(gtk.Dialog):
         engine_path = ''
         failure_string = ''
         arguments = '$IMAGE'
+        language_argument = ''
+        languages = ''
         if self.engine:
             name = self.engine.name
             image_format = self.engine.image_format
             failure_string = self.engine.failure_string
             engine_path = self.engine.engine_path
             arguments = self.engine.arguments
+            language_argument = self.engine.language_argument
+            languages = self.engine.serializeLanguages(self.engine.languages)
         box = gtk.VBox(True, 0)
         size_group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
         self.name_entry = gtk.Entry()
@@ -1749,6 +1883,25 @@ class OcrSettingsDialog(gtk.Dialog):
                                   self.arguments_entry, arguments,
                                   _('Arguments: use $IMAGE for image '
                                     'and $FILE if it writes to a file'))
+        self.language_argument_entry = gtk.Entry()
+        self.__packSettingInFrame(box, size_group,
+                                  _('Engine _language argument:'),
+                                  self.language_argument_entry, language_argument,
+                                  _('The language argument in case this engine '
+                                    'uses it (for example "-l"). In order for '
+                                    'it to work, the engine\'s arguments should '
+                                    'have the $LANG keyword.'))
+        self.languages_entry = gtk.Entry()
+        self.__packSettingInFrame(box, size_group,
+                                  _('Engine lan_guages:'),
+                                  self.languages_entry, languages,
+                                  _('The languages this engine supports. '
+                                    'This should be given as pairs of the '
+                                    'language in the ISO 639-1 and the '
+                                    'engine\'s corresponding language '
+                                    '(for example "en:eng,pt:por,es:esp"). '
+                                    'In order for it to work, the engine\'s '
+                                    'arguments should have the $LANG keyword.'))
         return box
 
     def setEngine(self):
@@ -1766,11 +1919,15 @@ class OcrSettingsDialog(gtk.Dialog):
             arguments = self.arguments_entry.get_text()
             image_format = self.image_format_entry.get_text()
             failure_string = self.failure_string_entry.get_text()
+            languages = self.languages_entry.get_text()
+            language_argument = self.language_argument_entry.get_text()
             engine = self.engine_manager.newEngine(self.name_entry.get_text(),
                                                    path,
                                                    arguments,
                                                    image_format,
                                                    failure_string,
+                                                   languages,
+                                                   language_argument,
                                                    version)
             if self.engine:
                 self.engine_manager.replaceEngine(self.engine, engine)
