@@ -25,16 +25,31 @@ import tempfile
 import shutil
 from xml.dom import minidom
 import os.path
+import locale
 
 PREDEFINED_ENGINES = {'tesseract': {'name': 'Tesseract',
                                     'image_format': 'TIF',
                                     'engine_path': 'tesseract',
-                                    'arguments': '$IMAGE $FILE >'
+                                    'arguments': '$LANG $IMAGE $FILE >'
                                     ' /dev/null 2> /dev/null; cat '
                                     '$FILE.txt; rm $FILE $FILE.txt',
-                                    'old_arguments': ['$IMAGE $FILE; cat '
+                                    'old_arguments': ['$IMAGE $FILE >'
+                                       ' /dev/null 2> /dev/null; cat '
+                                       '$FILE.txt; rm $FILE $FILE.txt',
+                                                  '$IMAGE $FILE; cat '
                                        '$FILE.txt; rm $FILE $FILE.txt'],
-                                    'version': 0.1},
+                                    'language_argument': '-l',
+                                    'languages': 'af:afr,ar:ara,az:aze,be:bel,'
+                                       'bn:ben,bg:bul,ca:cat,cs:cse,zh:chi-sim,'
+                                       'chr:chr,da:dan,de:deu,el:ell,en:eng,'
+                                       'et:est,eu:eus,fi:fin,fr:fra,gl:glg,he:heb,'
+                                       'hi:hin,hr:hrv,hu:hun,id:ind,is:isl,it:ita,'
+                                       'ja:jpn,kn:kan,ko:kor,lv:lav,lt:lit,ml:mal,'
+                                       'mk:mkd,mt:mlt,ms:msa,nl:nld,no:nor,pl:pol,'
+                                       'pt:por,ro:ron,ru:rus,sk:slk,sl:slv,es:spa,'
+                                       'sq:sqi,sr:srp,sw:swa,sv:swe,ta:tam,te:tel,'
+                                       'tl:tgl,th:tha,tr:tur,uk:ukr,vi:vie',
+                                    'version': 0.2},
                       'ocrad': {'name': 'Ocrad',
                                 'image_format': 'PPM',
                                 'engine_path': 'ocrad',
@@ -50,11 +65,19 @@ PREDEFINED_ENGINES = {'tesseract': {'name': 'Tesseract',
                       'cuneiform': {'name': 'Cuneiform',
                                'image_format': 'BMP',
                                'engine_path': 'cuneiform',
-                               'arguments': '-f text -o $FILE $IMAGE >'
+                               'arguments': '$LANG -f text -o $FILE $IMAGE >'
                                ' /dev/null 2> /dev/null && cat $FILE'
                                ' && rm $FILE',
-                               'old_arguments': [],
-                               'version': 0.0},
+                               'old_arguments': ['-f text -o $FILE $IMAGE >'
+                                      ' /dev/null 2> /dev/null && cat $FILE'
+                                      ' && rm $FILE'],
+                               'language_argument': '-l',
+                               'languages': 'en:eng,de:ger,fr:fra,ru:rus,sv:swe,'
+                                            'es:spa,it:ita,uk:ukr,'
+                                            'sr:srp,hr:hrv,pl:pol,da:dan,pt:por,'
+                                            'nl:dut,cs:cze,ro:rum,hu:hun,bg:bul,'
+                                            'sl:slv,lv:lav,lt:lit,et:est,tr:tur',
+                               'version': 0.1},
                      }
 
 class ConfigurationManager(object):
@@ -76,10 +99,10 @@ class ConfigurationManager(object):
     ADJUST_BOXES_BOUNDS = 'adjust_boxes_bounds'
     BOUNDS_ADJUSTMENT_SIZE = 'bounds_adjustment_size'
     DESKEW_IMAGES_AFTER_ADDITION = 'deskew_images_after_addition'
+    LANGUAGE = 'language'
 
     TEMPORARY_FOLDER = tempfile.mkdtemp(prefix = OCRFEEDER_COMPACT_NAME + '_')
 
-
     DEFAULTS = {TEXT_FILL: (94, 156, 235, 150),
                 BOXES_STROKE: (94, 156, 235, 250),
                 IMAGE_FILL: (0, 183, 0, 150),
@@ -97,6 +120,7 @@ class ConfigurationManager(object):
                 DESKEW_IMAGES_AFTER_ADDITION: False,
                 UNPAPER_IMAGES_AFTER_ADDITION: False,
                 UNPAPER_EXTRA_OPTIONS: '',
+                LANGUAGE: locale.getdefaultlocale()[0].split('_')[0],
                 }
 
     conf = dict(DEFAULTS)
@@ -131,12 +155,17 @@ class ConfigurationManager(object):
             image_format = PREDEFINED_ENGINES[name].get('image_format', 'PPM')
             failure_string = PREDEFINED_ENGINES[name].get('failure_string', '')
             version = PREDEFINED_ENGINES[name].get('version', 0.0)
+            language_argument = PREDEFINED_ENGINES[name].get('language_argument', '')
+            languages = PREDEFINED_ENGINES[name].get('languages', '')
+            favorite_language = PREDEFINED_ENGINES[name].get('favorite_language', '')
             engine = Engine(engine_name,
                             path,
                             arguments,
                             temporary_folder = self.TEMPORARY_FOLDER,
                             image_format = image_format,
                             failure_string = failure_string,
+                            languages = languages,
+                            language_argument = language_argument,
                             version = version)
             existing_engines.append(engine)
         return existing_engines
@@ -270,6 +299,13 @@ class ConfigurationManager(object):
     def setCleanText(self, clean_text):
         self.setConf(self.CLEAN_TEXT, clean_text)
 
+    def getLanguage(self):
+        lang = self.getConf(self.LANGUAGE)
+        return lang
+
+    def setLanguage(self, language):
+        self.setConf(self.LANGUAGE, language)
+
     def setAdjustBoxesBounds(self, adjust_boxes_bounds):
         self.setConf(self.ADJUST_BOXES_BOUNDS, adjust_boxes_bounds)
 
@@ -402,3 +438,5 @@ class ConfigurationManager(object):
 
     deskew_images_after_addition = property(getDeskewImagesAfterAddition,
                                             setDeskewImagesAfterAddition)
+
+    language = property(getLanguage, setLanguage)
