@@ -24,11 +24,11 @@ import locale
 
 OCRFEEDER_STUDIO_NAME = 'OCRFeeder'
 OCRFEEDER_COMPACT_NAME = 'ocrfeeder'
-OCRFEEDER_STUDIO_VERSION = '0.7.10'
-OCRFEEDER_STUDIO_AUTHORS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
-OCRFEEDER_STUDIO_ARTISTS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
-OCRFEEDER_COPYRIGHT = 'Copyright © 2008-2011 Joaquim Rocha\n' \
-                      'Copyright © 2009-2011 Igalia, SL'
+OCRFEEDER_STUDIO_VERSION = '0.7.11'
+OCRFEEDER_STUDIO_AUTHORS = ['Joaquim Rocha <me@joaquimrocha.com>']
+OCRFEEDER_STUDIO_ARTISTS = ['Joaquim Rocha <me@joaquimrocha.com>']
+OCRFEEDER_COPYRIGHT = 'Copyright © 2008-2013 Joaquim Rocha\n' \
+                      'Copyright © 2009-2012 Igalia, SL'
 OCRFEEDER_WEBSITE = 'http://live.gnome.org/OCRFeeder'
 GPL_STATEMENT = """
     OCRFeeder is free software: you can redistribute it and/or modify
@@ -47,14 +47,14 @@ GPL_STATEMENT = """
 OCRFEEDER_STUDIO_COMMENTS = 'The complete OCR suite.'
 
 # DIRECTORIES
-DEFAULT_SYSTEM_APP_DIR = os.path.join('/usr', 'share', 'ocrfeeder')
+DEFAULT_SYSTEM_APP_DIR = os.path.join('/usr/local', 'share', 'ocrfeeder')
 APP_DIR = DEFAULT_SYSTEM_APP_DIR
 RESOURCES_DIR = APP_DIR
 
 # If the path does not exist (devel setup) set the
 # APP_DIR and RESOURCES_DIR to local paths
 _dirname = os.path.abspath(os.path.dirname(__file__))
-if not os.path.exists(APP_DIR) or not _dirname.startswith('/usr'):
+if not os.path.exists(APP_DIR) or not _dirname.startswith('/usr/local'):
     APP_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
     RESOURCES_DIR = os.path.join(APP_DIR, '../../resources')
 RESOURCES_DIR = os.path.abspath(RESOURCES_DIR)
@@ -62,7 +62,7 @@ RESOURCES_DIR = os.path.abspath(RESOURCES_DIR)
 # I18N
 DEFAULT_LANGUAGES = os.environ.get('LANGUAGE', '').split(':')
 DEFAULT_LANGUAGES += ['en_US', 'pt_PT']
-LOCALE_DIR = os.path.join('/usr', 'share', 'locale')
+LOCALE_DIR = os.path.join('/usr/local', 'share', 'locale')
 OCRFEEDER_DEFAULT_LOCALE = locale.getdefaultlocale()[0]
 
 # CUSTOM ICONS
@@ -91,3 +91,6 @@ DTP = 72
 # UI files' location
 OCRFEEDER_SPELLCHECKER_UI = os.path.join(RESOURCES_DIR, 'spell-checker.ui')
 OCRFEEDER_MENUBAR_UI = os.path.join(RESOURCES_DIR, 'menubar.ui')
+
+# ISO-codes location
+ISO_CODES_PATH = '/usr/share/xml/iso-codes/'
